package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.system.service.IWechatMessageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WechatMessageMapper;
import com.ruoyi.system.domain.WechatMessage;

/**
 * 小程序信息发送Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-04-28
 */
@Service
public class WechatMessageServiceImpl implements IWechatMessageService
{
    @Autowired
    private WechatMessageMapper wechatMessageMapper;

    /**
     * 查询小程序信息发送
     * 
     * @param id 小程序信息发送主键
     * @return 小程序信息发送
     */
    @Override
    public WechatMessage selectWechatMessageById(String id)
    {
        return wechatMessageMapper.selectWechatMessageById(id);
    }

    /**
     * 查询小程序信息发送列表
     * 
     * @param wechatMessage 小程序信息发送
     * @return 小程序信息发送
     */
    @Override
    public List<WechatMessage> selectWechatMessageList(WechatMessage wechatMessage)
    {
        return wechatMessageMapper.selectWechatMessageList(wechatMessage);
    }

    /**
     * 新增小程序信息发送
     * 
     * @param wechatMessage 小程序信息发送
     * @return 结果
     */
    @Override
    public int insertWechatMessage(WechatMessage wechatMessage)
    {
        return wechatMessageMapper.insertWechatMessage(wechatMessage);
    }

    /**
     * 修改小程序信息发送
     * 
     * @param wechatMessage 小程序信息发送
     * @return 结果
     */
    @Override
    public int updateWechatMessage(WechatMessage wechatMessage)
    {
        return wechatMessageMapper.updateWechatMessage(wechatMessage);
    }

    /**
     * 批量删除小程序信息发送
     * 
     * @param ids 需要删除的小程序信息发送主键
     * @return 结果
     */
    @Override
    public int deleteWechatMessageByIds(String[] ids)
    {
        return wechatMessageMapper.deleteWechatMessageByIds(ids);
    }

    /**
     * 删除小程序信息发送信息
     * 
     * @param id 小程序信息发送主键
     * @return 结果
     */
    @Override
    public int deleteWechatMessageById(String id)
    {
        return wechatMessageMapper.deleteWechatMessageById(id);
    }
}
